package org.netkernel.xml.saxon.util;

import java.io.IOException;
import java.net.URL;

import org.apache.xml.resolver.Catalog;
import org.netkernel.container.ILogger;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.NKFException;
import org.netkernel.xml.util.NKFEntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;


public class CatalogNKFEntityResolver extends NKFEntityResolver
{
	private Catalog catalog;
	private INKFRequestContext context;
	
	public CatalogNKFEntityResolver(INKFRequestContext aContext) throws NKFException
	{
		super(aContext);
		context= aContext;
		catalog= aContext.source("active:catalogConfig", Catalog.class);
	}

	@Override
	public InputSource resolveEntity(String aPublicId, String systemId)
			throws SAXException, IOException
	{
		try
		{
			String resolved;
			if (aPublicId != null)
			{
				resolved = catalog.resolvePublic(aPublicId, systemId);
			} else
			{
				resolved = catalog.resolveSystem(systemId);
			}

			if (resolved != null)
			{
				URL resUrl = new URL(resolved);
				return new InputSource(resUrl.openConnection().getInputStream());
			}
		} catch (Exception e)
		{
			context.logRaw(ILogger.WARNING, "Exception in catalog resolver: " + e.getMessage());
		}

		return super.resolveEntity(aPublicId, systemId);
	}
}
